# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetFirewallTemplateResult',
    'AwaitableGetFirewallTemplateResult',
    'get_firewall_template',
    'get_firewall_template_output',
]

@pulumi.output_type
class GetFirewallTemplateResult:
    """
    A collection of values returned by getFirewallTemplate.
    """
    def __init__(__self__, id=None, inbound_policy=None, inbounds=None, outbound_policy=None, outbounds=None, slug=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if inbound_policy and not isinstance(inbound_policy, str):
            raise TypeError("Expected argument 'inbound_policy' to be a str")
        pulumi.set(__self__, "inbound_policy", inbound_policy)
        if inbounds and not isinstance(inbounds, list):
            raise TypeError("Expected argument 'inbounds' to be a list")
        pulumi.set(__self__, "inbounds", inbounds)
        if outbound_policy and not isinstance(outbound_policy, str):
            raise TypeError("Expected argument 'outbound_policy' to be a str")
        pulumi.set(__self__, "outbound_policy", outbound_policy)
        if outbounds and not isinstance(outbounds, list):
            raise TypeError("Expected argument 'outbounds' to be a list")
        pulumi.set(__self__, "outbounds", outbounds)
        if slug and not isinstance(slug, str):
            raise TypeError("Expected argument 'slug' to be a str")
        pulumi.set(__self__, "slug", slug)

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The computed ID of the data source, which matches the `slug` attribute.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="inboundPolicy")
    def inbound_policy(self) -> _builtins.str:
        """
        The default behavior for inbound traffic. This can be overridden by individual firewall rules.
        """
        return pulumi.get(self, "inbound_policy")

    @_builtins.property
    @pulumi.getter
    def inbounds(self) -> Sequence['outputs.GetFirewallTemplateInboundResult']:
        """
        A list of firewall rules specifying allowed inbound network traffic.
        """
        return pulumi.get(self, "inbounds")

    @_builtins.property
    @pulumi.getter(name="outboundPolicy")
    def outbound_policy(self) -> _builtins.str:
        """
        The default behavior for outbound traffic. This can be overridden by individual firewall rules.
        """
        return pulumi.get(self, "outbound_policy")

    @_builtins.property
    @pulumi.getter
    def outbounds(self) -> Sequence['outputs.GetFirewallTemplateOutboundResult']:
        """
        A list of firewall rules specifying allowed outbound network traffic.
        """
        return pulumi.get(self, "outbounds")

    @_builtins.property
    @pulumi.getter
    def slug(self) -> _builtins.str:
        return pulumi.get(self, "slug")


class AwaitableGetFirewallTemplateResult(GetFirewallTemplateResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetFirewallTemplateResult(
            id=self.id,
            inbound_policy=self.inbound_policy,
            inbounds=self.inbounds,
            outbound_policy=self.outbound_policy,
            outbounds=self.outbounds,
            slug=self.slug)


def get_firewall_template(slug: Optional[_builtins.str] = None,
                          opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetFirewallTemplateResult:
    """
    Provides information about a Linode Firewall Template.

    ## Example Usage

    The following example shows how one might use this data source to access information about a specific Firewall Template:

    ```python
    import pulumi
    import pulumi_linode as linode

    public_template = linode.get_firewall_template(slug="public")
    pulumi.export("firewallTemplateId", public_template.id)
    ```


    :param _builtins.str slug: The slug of the firewall template.
    """
    __args__ = dict()
    __args__['slug'] = slug
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('linode:index/getFirewallTemplate:getFirewallTemplate', __args__, opts=opts, typ=GetFirewallTemplateResult).value

    return AwaitableGetFirewallTemplateResult(
        id=pulumi.get(__ret__, 'id'),
        inbound_policy=pulumi.get(__ret__, 'inbound_policy'),
        inbounds=pulumi.get(__ret__, 'inbounds'),
        outbound_policy=pulumi.get(__ret__, 'outbound_policy'),
        outbounds=pulumi.get(__ret__, 'outbounds'),
        slug=pulumi.get(__ret__, 'slug'))
def get_firewall_template_output(slug: Optional[pulumi.Input[_builtins.str]] = None,
                                 opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetFirewallTemplateResult]:
    """
    Provides information about a Linode Firewall Template.

    ## Example Usage

    The following example shows how one might use this data source to access information about a specific Firewall Template:

    ```python
    import pulumi
    import pulumi_linode as linode

    public_template = linode.get_firewall_template(slug="public")
    pulumi.export("firewallTemplateId", public_template.id)
    ```


    :param _builtins.str slug: The slug of the firewall template.
    """
    __args__ = dict()
    __args__['slug'] = slug
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('linode:index/getFirewallTemplate:getFirewallTemplate', __args__, opts=opts, typ=GetFirewallTemplateResult)
    return __ret__.apply(lambda __response__: GetFirewallTemplateResult(
        id=pulumi.get(__response__, 'id'),
        inbound_policy=pulumi.get(__response__, 'inbound_policy'),
        inbounds=pulumi.get(__response__, 'inbounds'),
        outbound_policy=pulumi.get(__response__, 'outbound_policy'),
        outbounds=pulumi.get(__response__, 'outbounds'),
        slug=pulumi.get(__response__, 'slug')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetAccountLoginResult',
    'AwaitableGetAccountLoginResult',
    'get_account_login',
    'get_account_login_output',
]

@pulumi.output_type
class GetAccountLoginResult:
    """
    A collection of values returned by getAccountLogin.
    """
    def __init__(__self__, datetime=None, id=None, ip=None, restricted=None, status=None, username=None):
        if datetime and not isinstance(datetime, str):
            raise TypeError("Expected argument 'datetime' to be a str")
        pulumi.set(__self__, "datetime", datetime)
        if id and not isinstance(id, int):
            raise TypeError("Expected argument 'id' to be a int")
        pulumi.set(__self__, "id", id)
        if ip and not isinstance(ip, str):
            raise TypeError("Expected argument 'ip' to be a str")
        pulumi.set(__self__, "ip", ip)
        if restricted and not isinstance(restricted, bool):
            raise TypeError("Expected argument 'restricted' to be a bool")
        pulumi.set(__self__, "restricted", restricted)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if username and not isinstance(username, str):
            raise TypeError("Expected argument 'username' to be a str")
        pulumi.set(__self__, "username", username)

    @_builtins.property
    @pulumi.getter
    def datetime(self) -> _builtins.str:
        """
        When the login was initiated.
        """
        return pulumi.get(self, "datetime")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.int:
        """
        The unique ID of this login object.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def ip(self) -> _builtins.str:
        """
        The remote IP address that requested the login.
        """
        return pulumi.get(self, "ip")

    @_builtins.property
    @pulumi.getter
    def restricted(self) -> _builtins.bool:
        """
        True if the User that was logged into was a restricted User, false otherwise.
        """
        return pulumi.get(self, "restricted")

    @_builtins.property
    @pulumi.getter
    def status(self) -> _builtins.str:
        return pulumi.get(self, "status")

    @_builtins.property
    @pulumi.getter
    def username(self) -> _builtins.str:
        """
        The username of the User that was logged into.
        """
        return pulumi.get(self, "username")


class AwaitableGetAccountLoginResult(GetAccountLoginResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetAccountLoginResult(
            datetime=self.datetime,
            id=self.id,
            ip=self.ip,
            restricted=self.restricted,
            status=self.status,
            username=self.username)


def get_account_login(id: Optional[_builtins.int] = None,
                      opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetAccountLoginResult:
    """
    Provides details about a specific Linode account login.
    For more information, see the [Linode APIv4 docs](https://techdocs.akamai.com/linode-api/reference/get-account-login).

    ## Example Usage

    The following example shows how one might use this data source to access information about a Linode account login.

    ```python
    import pulumi
    import pulumi_linode as linode

    my_account_login = linode.get_account_login(id=123456)
    ```


    :param _builtins.int id: The unique ID of this login object.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('linode:index/getAccountLogin:getAccountLogin', __args__, opts=opts, typ=GetAccountLoginResult).value

    return AwaitableGetAccountLoginResult(
        datetime=pulumi.get(__ret__, 'datetime'),
        id=pulumi.get(__ret__, 'id'),
        ip=pulumi.get(__ret__, 'ip'),
        restricted=pulumi.get(__ret__, 'restricted'),
        status=pulumi.get(__ret__, 'status'),
        username=pulumi.get(__ret__, 'username'))
def get_account_login_output(id: Optional[pulumi.Input[_builtins.int]] = None,
                             opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetAccountLoginResult]:
    """
    Provides details about a specific Linode account login.
    For more information, see the [Linode APIv4 docs](https://techdocs.akamai.com/linode-api/reference/get-account-login).

    ## Example Usage

    The following example shows how one might use this data source to access information about a Linode account login.

    ```python
    import pulumi
    import pulumi_linode as linode

    my_account_login = linode.get_account_login(id=123456)
    ```


    :param _builtins.int id: The unique ID of this login object.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('linode:index/getAccountLogin:getAccountLogin', __args__, opts=opts, typ=GetAccountLoginResult)
    return __ret__.apply(lambda __response__: GetAccountLoginResult(
        datetime=pulumi.get(__response__, 'datetime'),
        id=pulumi.get(__response__, 'id'),
        ip=pulumi.get(__response__, 'ip'),
        restricted=pulumi.get(__response__, 'restricted'),
        status=pulumi.get(__response__, 'status'),
        username=pulumi.get(__response__, 'username')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['Ipv6RangeArgs', 'Ipv6Range']

@pulumi.input_type
class Ipv6RangeArgs:
    def __init__(__self__, *,
                 prefix_length: pulumi.Input[_builtins.int],
                 linode_id: Optional[pulumi.Input[_builtins.int]] = None,
                 route_target: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a Ipv6Range resource.
        :param pulumi.Input[_builtins.int] prefix_length: The prefix length of the IPv6 range.
        :param pulumi.Input[_builtins.int] linode_id: The ID of the Linode to assign this range to. This field may be updated to reassign the IPv6 range.
        :param pulumi.Input[_builtins.str] route_target: The IPv6 SLAAC address to assign this range to.
        """
        pulumi.set(__self__, "prefix_length", prefix_length)
        if linode_id is not None:
            pulumi.set(__self__, "linode_id", linode_id)
        if route_target is not None:
            pulumi.set(__self__, "route_target", route_target)

    @_builtins.property
    @pulumi.getter(name="prefixLength")
    def prefix_length(self) -> pulumi.Input[_builtins.int]:
        """
        The prefix length of the IPv6 range.
        """
        return pulumi.get(self, "prefix_length")

    @prefix_length.setter
    def prefix_length(self, value: pulumi.Input[_builtins.int]):
        pulumi.set(self, "prefix_length", value)

    @_builtins.property
    @pulumi.getter(name="linodeId")
    def linode_id(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The ID of the Linode to assign this range to. This field may be updated to reassign the IPv6 range.
        """
        return pulumi.get(self, "linode_id")

    @linode_id.setter
    def linode_id(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "linode_id", value)

    @_builtins.property
    @pulumi.getter(name="routeTarget")
    def route_target(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The IPv6 SLAAC address to assign this range to.
        """
        return pulumi.get(self, "route_target")

    @route_target.setter
    def route_target(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "route_target", value)


@pulumi.input_type
class _Ipv6RangeState:
    def __init__(__self__, *,
                 is_bgp: Optional[pulumi.Input[_builtins.bool]] = None,
                 linode_id: Optional[pulumi.Input[_builtins.int]] = None,
                 linodes: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.int]]]] = None,
                 prefix_length: Optional[pulumi.Input[_builtins.int]] = None,
                 range: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 route_target: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering Ipv6Range resources.
        :param pulumi.Input[_builtins.bool] is_bgp: Whether this IPv6 range is shared.
        :param pulumi.Input[_builtins.int] linode_id: The ID of the Linode to assign this range to. This field may be updated to reassign the IPv6 range.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.int]]] linodes: A list of Linodes targeted by this IPv6 range. Includes Linodes with IP sharing.
        :param pulumi.Input[_builtins.int] prefix_length: The prefix length of the IPv6 range.
        :param pulumi.Input[_builtins.str] range: The IPv6 range of addresses in this pool.
        :param pulumi.Input[_builtins.str] region: The region for this range of IPv6 addresses.
        :param pulumi.Input[_builtins.str] route_target: The IPv6 SLAAC address to assign this range to.
        """
        if is_bgp is not None:
            pulumi.set(__self__, "is_bgp", is_bgp)
        if linode_id is not None:
            pulumi.set(__self__, "linode_id", linode_id)
        if linodes is not None:
            pulumi.set(__self__, "linodes", linodes)
        if prefix_length is not None:
            pulumi.set(__self__, "prefix_length", prefix_length)
        if range is not None:
            pulumi.set(__self__, "range", range)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if route_target is not None:
            pulumi.set(__self__, "route_target", route_target)

    @_builtins.property
    @pulumi.getter(name="isBgp")
    def is_bgp(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether this IPv6 range is shared.
        """
        return pulumi.get(self, "is_bgp")

    @is_bgp.setter
    def is_bgp(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "is_bgp", value)

    @_builtins.property
    @pulumi.getter(name="linodeId")
    def linode_id(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The ID of the Linode to assign this range to. This field may be updated to reassign the IPv6 range.
        """
        return pulumi.get(self, "linode_id")

    @linode_id.setter
    def linode_id(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "linode_id", value)

    @_builtins.property
    @pulumi.getter
    def linodes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.int]]]]:
        """
        A list of Linodes targeted by this IPv6 range. Includes Linodes with IP sharing.
        """
        return pulumi.get(self, "linodes")

    @linodes.setter
    def linodes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.int]]]]):
        pulumi.set(self, "linodes", value)

    @_builtins.property
    @pulumi.getter(name="prefixLength")
    def prefix_length(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The prefix length of the IPv6 range.
        """
        return pulumi.get(self, "prefix_length")

    @prefix_length.setter
    def prefix_length(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "prefix_length", value)

    @_builtins.property
    @pulumi.getter
    def range(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The IPv6 range of addresses in this pool.
        """
        return pulumi.get(self, "range")

    @range.setter
    def range(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "range", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The region for this range of IPv6 addresses.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter(name="routeTarget")
    def route_target(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The IPv6 SLAAC address to assign this range to.
        """
        return pulumi.get(self, "route_target")

    @route_target.setter
    def route_target(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "route_target", value)


@pulumi.type_token("linode:index/ipv6Range:Ipv6Range")
class Ipv6Range(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 linode_id: Optional[pulumi.Input[_builtins.int]] = None,
                 prefix_length: Optional[pulumi.Input[_builtins.int]] = None,
                 route_target: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_linode as linode

        foobar = linode.Instance("foobar",
            label="my-linode",
            image="linode/alpine3.19",
            type="g6-nanode-1",
            region="us-southeast")
        foobar_ipv6_range = linode.Ipv6Range("foobar",
            linode_id=foobar.id,
            prefix_length=64)
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.int] linode_id: The ID of the Linode to assign this range to. This field may be updated to reassign the IPv6 range.
        :param pulumi.Input[_builtins.int] prefix_length: The prefix length of the IPv6 range.
        :param pulumi.Input[_builtins.str] route_target: The IPv6 SLAAC address to assign this range to.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Ipv6RangeArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_linode as linode

        foobar = linode.Instance("foobar",
            label="my-linode",
            image="linode/alpine3.19",
            type="g6-nanode-1",
            region="us-southeast")
        foobar_ipv6_range = linode.Ipv6Range("foobar",
            linode_id=foobar.id,
            prefix_length=64)
        ```

        :param str resource_name: The name of the resource.
        :param Ipv6RangeArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(Ipv6RangeArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 linode_id: Optional[pulumi.Input[_builtins.int]] = None,
                 prefix_length: Optional[pulumi.Input[_builtins.int]] = None,
                 route_target: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = Ipv6RangeArgs.__new__(Ipv6RangeArgs)

            __props__.__dict__["linode_id"] = linode_id
            if prefix_length is None and not opts.urn:
                raise TypeError("Missing required property 'prefix_length'")
            __props__.__dict__["prefix_length"] = prefix_length
            __props__.__dict__["route_target"] = route_target
            __props__.__dict__["is_bgp"] = None
            __props__.__dict__["linodes"] = None
            __props__.__dict__["range"] = None
            __props__.__dict__["region"] = None
        super(Ipv6Range, __self__).__init__(
            'linode:index/ipv6Range:Ipv6Range',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            is_bgp: Optional[pulumi.Input[_builtins.bool]] = None,
            linode_id: Optional[pulumi.Input[_builtins.int]] = None,
            linodes: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.int]]]] = None,
            prefix_length: Optional[pulumi.Input[_builtins.int]] = None,
            range: Optional[pulumi.Input[_builtins.str]] = None,
            region: Optional[pulumi.Input[_builtins.str]] = None,
            route_target: Optional[pulumi.Input[_builtins.str]] = None) -> 'Ipv6Range':
        """
        Get an existing Ipv6Range resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.bool] is_bgp: Whether this IPv6 range is shared.
        :param pulumi.Input[_builtins.int] linode_id: The ID of the Linode to assign this range to. This field may be updated to reassign the IPv6 range.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.int]]] linodes: A list of Linodes targeted by this IPv6 range. Includes Linodes with IP sharing.
        :param pulumi.Input[_builtins.int] prefix_length: The prefix length of the IPv6 range.
        :param pulumi.Input[_builtins.str] range: The IPv6 range of addresses in this pool.
        :param pulumi.Input[_builtins.str] region: The region for this range of IPv6 addresses.
        :param pulumi.Input[_builtins.str] route_target: The IPv6 SLAAC address to assign this range to.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _Ipv6RangeState.__new__(_Ipv6RangeState)

        __props__.__dict__["is_bgp"] = is_bgp
        __props__.__dict__["linode_id"] = linode_id
        __props__.__dict__["linodes"] = linodes
        __props__.__dict__["prefix_length"] = prefix_length
        __props__.__dict__["range"] = range
        __props__.__dict__["region"] = region
        __props__.__dict__["route_target"] = route_target
        return Ipv6Range(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="isBgp")
    def is_bgp(self) -> pulumi.Output[_builtins.bool]:
        """
        Whether this IPv6 range is shared.
        """
        return pulumi.get(self, "is_bgp")

    @_builtins.property
    @pulumi.getter(name="linodeId")
    def linode_id(self) -> pulumi.Output[Optional[_builtins.int]]:
        """
        The ID of the Linode to assign this range to. This field may be updated to reassign the IPv6 range.
        """
        return pulumi.get(self, "linode_id")

    @_builtins.property
    @pulumi.getter
    def linodes(self) -> pulumi.Output[Sequence[_builtins.int]]:
        """
        A list of Linodes targeted by this IPv6 range. Includes Linodes with IP sharing.
        """
        return pulumi.get(self, "linodes")

    @_builtins.property
    @pulumi.getter(name="prefixLength")
    def prefix_length(self) -> pulumi.Output[_builtins.int]:
        """
        The prefix length of the IPv6 range.
        """
        return pulumi.get(self, "prefix_length")

    @_builtins.property
    @pulumi.getter
    def range(self) -> pulumi.Output[_builtins.str]:
        """
        The IPv6 range of addresses in this pool.
        """
        return pulumi.get(self, "range")

    @_builtins.property
    @pulumi.getter
    def region(self) -> pulumi.Output[_builtins.str]:
        """
        The region for this range of IPv6 addresses.
        """
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter(name="routeTarget")
    def route_target(self) -> pulumi.Output[_builtins.str]:
        """
        The IPv6 SLAAC address to assign this range to.
        """
        return pulumi.get(self, "route_target")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetIpv6RangesResult',
    'AwaitableGetIpv6RangesResult',
    'get_ipv6_ranges',
    'get_ipv6_ranges_output',
]

@pulumi.output_type
class GetIpv6RangesResult:
    """
    A collection of values returned by getIpv6Ranges.
    """
    def __init__(__self__, filters=None, id=None, ranges=None):
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        pulumi.set(__self__, "filters", filters)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ranges and not isinstance(ranges, list):
            raise TypeError("Expected argument 'ranges' to be a list")
        pulumi.set(__self__, "ranges", ranges)

    @_builtins.property
    @pulumi.getter
    def filters(self) -> Optional[Sequence['outputs.GetIpv6RangesFilterResult']]:
        return pulumi.get(self, "filters")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def ranges(self) -> Optional[Sequence['outputs.GetIpv6RangesRangeResult']]:
        return pulumi.get(self, "ranges")


class AwaitableGetIpv6RangesResult(GetIpv6RangesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetIpv6RangesResult(
            filters=self.filters,
            id=self.id,
            ranges=self.ranges)


def get_ipv6_ranges(filters: Optional[Sequence[Union['GetIpv6RangesFilterArgs', 'GetIpv6RangesFilterArgsDict']]] = None,
                    ranges: Optional[Sequence[Union['GetIpv6RangesRangeArgs', 'GetIpv6RangesRangeArgsDict']]] = None,
                    opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetIpv6RangesResult:
    """
    Provides information about Linode IPv6 ranges that match a set of filters.
    For more information, see the [Linode APIv4 docs](https://techdocs.akamai.com/linode-api/reference/get-ipv6-ranges).

    > Some fields may not be accessible directly the results of this data source.
    For additional information about a specific IPv6 range consider using the Ipv6Range
    data source.

    ```python
    import pulumi
    import pulumi_linode as linode

    filtered_ranges = linode.get_ipv6_ranges(filters=[{
        "name": "region",
        "values": ["us-mia"],
    }])
    pulumi.export("ranges", filtered_ranges)
    ```

    ## Filterable Fields

    * `range`

    * `route_target`

    * `prefix`

    * `region`
    """
    __args__ = dict()
    __args__['filters'] = filters
    __args__['ranges'] = ranges
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('linode:index/getIpv6Ranges:getIpv6Ranges', __args__, opts=opts, typ=GetIpv6RangesResult).value

    return AwaitableGetIpv6RangesResult(
        filters=pulumi.get(__ret__, 'filters'),
        id=pulumi.get(__ret__, 'id'),
        ranges=pulumi.get(__ret__, 'ranges'))
def get_ipv6_ranges_output(filters: Optional[pulumi.Input[Optional[Sequence[Union['GetIpv6RangesFilterArgs', 'GetIpv6RangesFilterArgsDict']]]]] = None,
                           ranges: Optional[pulumi.Input[Optional[Sequence[Union['GetIpv6RangesRangeArgs', 'GetIpv6RangesRangeArgsDict']]]]] = None,
                           opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetIpv6RangesResult]:
    """
    Provides information about Linode IPv6 ranges that match a set of filters.
    For more information, see the [Linode APIv4 docs](https://techdocs.akamai.com/linode-api/reference/get-ipv6-ranges).

    > Some fields may not be accessible directly the results of this data source.
    For additional information about a specific IPv6 range consider using the Ipv6Range
    data source.

    ```python
    import pulumi
    import pulumi_linode as linode

    filtered_ranges = linode.get_ipv6_ranges(filters=[{
        "name": "region",
        "values": ["us-mia"],
    }])
    pulumi.export("ranges", filtered_ranges)
    ```

    ## Filterable Fields

    * `range`

    * `route_target`

    * `prefix`

    * `region`
    """
    __args__ = dict()
    __args__['filters'] = filters
    __args__['ranges'] = ranges
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('linode:index/getIpv6Ranges:getIpv6Ranges', __args__, opts=opts, typ=GetIpv6RangesResult)
    return __ret__.apply(lambda __response__: GetIpv6RangesResult(
        filters=pulumi.get(__response__, 'filters'),
        id=pulumi.get(__response__, 'id'),
        ranges=pulumi.get(__response__, 'ranges')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetDatabaseMysqlConfigResult',
    'AwaitableGetDatabaseMysqlConfigResult',
    'get_database_mysql_config',
    'get_database_mysql_config_output',
]

@pulumi.output_type
class GetDatabaseMysqlConfigResult:
    """
    A collection of values returned by getDatabaseMysqlConfig.
    """
    def __init__(__self__, binlog_retention_periods=None, id=None, mysqls=None):
        if binlog_retention_periods and not isinstance(binlog_retention_periods, list):
            raise TypeError("Expected argument 'binlog_retention_periods' to be a list")
        pulumi.set(__self__, "binlog_retention_periods", binlog_retention_periods)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if mysqls and not isinstance(mysqls, list):
            raise TypeError("Expected argument 'mysqls' to be a list")
        pulumi.set(__self__, "mysqls", mysqls)

    @_builtins.property
    @pulumi.getter(name="binlogRetentionPeriods")
    def binlog_retention_periods(self) -> Sequence['outputs.GetDatabaseMysqlConfigBinlogRetentionPeriodResult']:
        return pulumi.get(self, "binlog_retention_periods")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def mysqls(self) -> Sequence['outputs.GetDatabaseMysqlConfigMysqlResult']:
        return pulumi.get(self, "mysqls")


class AwaitableGetDatabaseMysqlConfigResult(GetDatabaseMysqlConfigResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetDatabaseMysqlConfigResult(
            binlog_retention_periods=self.binlog_retention_periods,
            id=self.id,
            mysqls=self.mysqls)


def get_database_mysql_config(opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetDatabaseMysqlConfigResult:
    """
    Provides information about a Linode MySQL Database's Configuration Options.
    For more information, see the Linode APIv4 docs.

    ## Example Usage

    Get information about a MySQL database's configuration options:

    ```python
    import pulumi
    import pulumi_linode as linode

    my_db_config = linode.get_database_mysql_config()
    ```

    ## binlog_retention_period

    The following arguments are supported in the `binlog_retention_period` specification block:

    * `description` - The description of `binlog_retention_period`.

    * `example` - An example of a valid value for `binlog_retention_period`.

    * `maximum` - The maximum valid value of `binlog_retention_period`.

    * `minimum` - The minimum valid value of `binlog_retention_period`.

    * `requires_restart` - Whether changing the value `binlog_retention_period` requires the DB to restart.

    * `type` - The type of the value of `binlog_retention_period`.

    ## mysql

    The following arguments are supported in the `mysql` specification block:

    * `connect_timeout` - The number of seconds that the mysqld server waits for a connect packet before responding with "Bad handshake".

    * `default_time_zone` - Default server time zone as an offset from UTC (from -12:00 to +12:00), a time zone name, or `SYSTEM` to use the MySQL server default.

    * `group_concat_max_len` - The maximum permitted result length in bytes for the `GROUP_CONCAT()` function.

    * `information_schema_stats_expiry` - The time, in seconds, before cached statistics expire.

    * `innodb_change_buffer_max_size` - Maximum size for the InnoDB change buffer, as a percentage of the total size of the buffer pool. Default is 25.

    * `innodb_flush_neighbors` - Specifies whether flushing a page from the InnoDB buffer pool also flushes other dirty pages in the same extent (default is 1): 0 - dirty pages in the same extent are not flushed, 1 - flush contiguous dirty pages in the same extent, 2 - flush dirty pages in the same extent.

    * `innodb_ft_min_token_size` - Minimum length of words that are stored in an InnoDB FULLTEXT index. Changing this parameter will lead to a restart of the MySQL service.

    * `innodb_ft_server_stopword_table` - This option is used to specify your own InnoDB FULLTEXT index stopword list for all InnoDB tables.

    * `innodb_lock_wait_timeout` - The length of time in seconds an InnoDB transaction waits for a row lock before giving up. Default is 120.

    * `innodb_log_buffer_size` - The size in bytes of the buffer that InnoDB uses to write to the log files on disk.

    * `innodb_online_alter_log_max_size` - The upper limit in bytes on the size of the temporary log files used during online DDL operations for InnoDB tables.

    * `innodb_read_io_threads` - The number of I/O threads for read operations in InnoDB. Default is 4. Changing this parameter will lead to a restart of the MySQL service.

    * `innodb_rollback_on_timeout` - When enabled, a transaction timeout causes InnoDB to abort and roll back the entire transaction. Changing this parameter will lead to a restart of the MySQL service.

    * `innodb_thread_concurrency` - Defines the maximum number of threads permitted inside of InnoDB. Default is 0 (infinite concurrency - no limit).

    * `innodb_write_io_threads` - The number of I/O threads for write operations in InnoDB. Default is 4. Changing this parameter will lead to a restart of the MySQL service.

    * `interactive_timeout` - The number of seconds the server waits for activity on an interactive connection before closing it.

    * `internal_tmp_mem_storage_engine` - The storage engine for in-memory internal temporary tables.

    * `max_allowed_packet` - Size of the largest message in bytes that can be received by the server. Default is 67108864 (64M).

    * `max_heap_table_size` - Limits the size of internal in-memory tables. Also set tmp_table_size. Default is 16777216 (16M).

    * `net_buffer_length` - Start sizes of connection buffer and result buffer. Default is 16384 (16K). Changing this parameter will lead to a restart of the MySQL service.

    * `net_read_timeout` - The number of seconds to wait for more data from a connection before aborting the read.

    * `net_write_timeout` - The number of seconds to wait for a block to be written to a connection before aborting the write.

    * `sort_buffer_size` - Sort buffer size in bytes for ORDER BY optimization. Default is 262144 (256K).

    * `sql_mode` - Global SQL mode. Set to empty to use MySQL server defaults. When creating a new service and not setting this field Aiven default SQL mode (strict, SQL standard compliant) will be assigned.

    * `sql_require_primary_key` - Require primary key to be defined for new tables or old tables modified with ALTER TABLE and fail if missing. It is recommended to always have primary keys because various functionality may break if any large table is missing them.

    * `tmp_table_size` - Limits the size of internal in-memory tables. Also set max_heap_table_size. Default is 16777216 (16M).

    * `wait_timeout` - The number of seconds the server waits for activity on a noninteractive connection before closing it.

    ## connect_timeout

    The following arguments are supported in the `connect_timeout` specification block:

    * `description` - The description of `connect_timeout`.

    * `example` - An example of a valid value for `connect_timeout`.

    * `maximum` - The maximum valid value of  `connect_timeout`.

    * `minimum` - The minimum valid value of  `connect_timeout`.

    * `requires_restart` - Whether changing the value `connect_timeout` requires the DB to restart.

    * `type` - The type of the value of `connect_timeout`.

    ## default_time_zone

    The following arguments are supported in the `default_time_zone` specification block:

    * `description` - The description of `default_time_zone`.

    * `example` - An example of a valid value for `default_time_zone`.

    * `maxLength` - The maximum length of the `default_time_zone` value.

    * `minLength` - The minimum length of the `default_time_zone` value.

    * `pattern` - A regular expression that the `default_time_zone` value must match.

    * `requires_restart` - Whether changing the value `default_time_zone` requires the DB to restart.

    * `type` - The type of the value of `default_time_zone`.

    ## group_concat_max_len

    The following arguments are supported in the `group_concat_max_len` specification block:

    * `description` - The description of `group_concat_max_len`.

    * `example` - An example of a valid value for `group_concat_max_len`.

    * `maximum` - The maximum valid value of `group_concat_max_len`.

    * `minimum` - The minimum valid value of `group_concat_max_len`.

    * `requires_restart` - Whether changing the value `group_concat_max_len` requires the DB to restart.

    * `type` - The type of the value of `group_concat_max_len`.

    ## information_schema_stats_expiry

    The following arguments are supported in the `information_schema_stats_expiry` specification block:

    * `description` - The description of `information_schema_stats_expiry`.

    * `example` - An example of a valid value for `information_schema_stats_expiry`.

    * `maximum` - The maximum valid value of `information_schema_stats_expiry`.

    * `minimum` - The minimum valid value of `information_schema_stats_expiry`.

    * `requires_restart` - Whether changing the value `information_schema_stats_expiry` requires the DB to restart.

    * `type` - The type of the value of `information_schema_stats_expiry`.

    ## innodb_change_buffer_max_size

    The following arguments are supported in the `innodb_change_buffer_max_size` specification block:

    * `description` - The description of `innodb_change_buffer_max_size`.

    * `example` - An example of a valid value for `innodb_change_buffer_max_size`.

    * `maximum` - The maximum valid value of `innodb_change_buffer_max_size`.

    * `minimum` - The minimum valid value of `innodb_change_buffer_max_size`.

    * `requires_restart` - Whether changing the value `innodb_change_buffer_max_size` requires the DB to restart.

    * `type` - The type of the value of `innodb_change_buffer_max_size`.

    ## innodb_flush_neighbors

    The following arguments are supported in the `innodb_flush_neighbors` specification block:

    * `description` - The description of `innodb_flush_neighbors`.

    * `example` - An example of a valid value for `innodb_flush_neighbors`.

    * `maximum` - The maximum valid value of `innodb_flush_neighbors`.

    * `minimum` - The minimum valid value of `innodb_flush_neighbors`.

    * `requires_restart` - Whether changing the value `innodb_flush_neighbors` requires the DB to restart.

    * `type` - The type of the value of `innodb_flush_neighbors`.

    ## innodb_ft_min_token_size

    The following arguments are supported in the `innodb_ft_min_token_size` specification block:

    * `description` - The description of `innodb_ft_min_token_size`.

    * `example` - An example of a valid value for `innodb_ft_min_token_size`.

    * `maximum` - The maximum valid value of `innodb_ft_min_token_size`.

    * `minimum` - The minimum valid value of `innodb_ft_min_token_size`.

    * `requires_restart` - Whether changing the value `innodb_ft_min_token_size` requires the DB to restart.

    * `type` - The type of the value of `innodb_ft_min_token_size`.

    ## innodb_ft_server_stopword_table

    The following arguments are supported in the `innodb_ft_server_stopword_table` specification block:

    * `description` - The description of `innodb_ft_server_stopword_table`.

    * `example` - An example of a valid value for `innodb_ft_server_stopword_table`.

    * `maxLength` - The maximum length of the value for `innodb_ft_server_stopword_table`.

    * `pattern` - A regex pattern that a value of `innodb_ft_server_stopword_table` must match.

    * `requires_restart` - Whether changing the value `innodb_ft_server_stopword_table` requires the DB to restart.

    * `type` - The type of the value of `innodb_ft_server_stopword_table`.

    ## innodb_lock_wait_timeout

    The following arguments are supported in the `innodb_lock_wait_timeout` specification block:

    * `description` - The description of `innodb_lock_wait_timeout`.

    * `example` - An example of a valid value for `innodb_lock_wait_timeout`.

    * `maximum` - The maximum valid value of `innodb_lock_wait_timeout`.

    * `minimum` - The minimum valid value of `innodb_lock_wait_timeout`.

    * `requires_restart` - Whether changing the value `innodb_lock_wait_timeout` requires the DB to restart.

    * `type` - The type of the value of `innodb_lock_wait_timeout`.

    ## innodb_log_buffer_size

    The following arguments are supported in the `innodb_log_buffer_size` specification block:

    * `description` - The description of `innodb_log_buffer_size`.

    * `example` - An example of a valid value for `innodb_log_buffer_size`.

    * `maximum` - The maximum valid value of `innodb_log_buffer_size`.

    * `minimum` - The minimum valid value of `innodb_log_buffer_size`.

    * `requires_restart` - Whether changing the value `innodb_log_buffer_size` requires the DB to restart.

    * `type` - The type of the value of `innodb_log_buffer_size`.

    ## innodb_online_alter_log_max_size

    The following arguments are supported in the `innodb_online_alter_log_max_size` specification block:

    * `description` - The description of `innodb_online_alter_log_max_size`.

    * `example` - An example of a valid value for `innodb_online_alter_log_max_size`.

    * `maximum` - The maximum valid value of `innodb_online_alter_log_max_size`.

    * `minimum` - The minimum valid value of `innodb_online_alter_log_max_size`.

    * `requires_restart` - Whether changing the value `innodb_online_alter_log_max_size` requires the DB to restart.

    * `type` - The type of the value of `innodb_online_alter_log_max_size`.

    ## innodb_read_io_threads

    The following arguments are supported in the `innodb_read_io_threads` specification block:

    * `description` - The description of `innodb_read_io_threads`.

    * `example` - An example of a valid value for `innodb_read_io_threads`.

    * `maximum` - The maximum valid value of `innodb_read_io_threads`.

    * `minimum` - The minimum valid value of `innodb_read_io_threads`.

    * `requires_restart` - Whether changing the value `innodb_read_io_threads` requires the DB to restart.

    * `type` - The type of the value of `innodb_read_io_threads`.

    ## innodb_rollback_on_timeout

    The following arguments are supported in the `innodb_rollback_on_timeout` specification block:

    * `description` - The description of `innodb_rollback_on_timeout`.

    * `example` - An example of a valid value for `innodb_rollback_on_timeout`.

    * `requires_restart` - Whether changing the value `innodb_rollback_on_timeout` requires the DB to restart.

    * `type` - The type of the value of `innodb_rollback_on_timeout`.

    ## innodb_thread_concurrency

    The following arguments are supported in the `innodb_thread_concurrency` specification block:

    * `description` - The description of `innodb_thread_concurrency`.

    * `example` - An example of a valid value for `innodb_thread_concurrency`.

    * `maximum` - The maximum valid value of `innodb_thread_concurrency`.

    * `minimum` - The minimum valid value of `innodb_thread_concurrency`.

    * `requires_restart` - Whether changing the value `innodb_thread_concurrency` requires the DB to restart.

    * `type` - The type of the value of `innodb_thread_concurrency`.

    ## innodb_write_io_threads

    The following arguments are supported in the `innodb_write_io_threads` specification block:

    * `description` - The description of `innodb_write_io_threads`.

    * `example` - An example of a valid value for `innodb_write_io_threads`.

    * `maximum` - The maximum valid value of `innodb_write_io_threads`.

    * `minimum` - The minimum valid value of `innodb_write_io_threads`.

    * `requires_restart` - Whether changing the value `innodb_write_io_threads` requires the DB to restart.

    * `type` - The type of the value of `innodb_write_io_threads`.

    ## interactive_timeout

    The following arguments are supported in the `interactive_timeout` specification block:

    * `description` - The description of `interactive_timeout`.

    * `example` - An example of a valid value for `interactive_timeout`.

    * `maximum` - The maximum valid value of `interactive_timeout`.

    * `minimum` - The minimum valid value of `interactive_timeout`.

    * `requires_restart` - Whether changing the value `interactive_timeout` requires the DB to restart.

    * `type` - The type of the value of `interactive_timeout`.

    ## internal_tmp_mem_storage_engine

    The following arguments are supported in the `internal_tmp_mem_storage_engine` specification block:

    * `description` - The description of `internal_tmp_mem_storage_engine`.

    * `enum` - A list of valid enum values for `internal_tmp_mem_storage_engine`.

    * `example` - An example of a valid value for `internal_tmp_mem_storage_engine`.

    * `requires_restart` - Whether changing the value `internal_tmp_mem_storage_engine` requires the DB to restart.

    * `type` - The type of the value of `internal_tmp_mem_storage_engine`.

    ## max_allowed_packet

    The following arguments are supported in the `max_allowed_packet` specification block:

    * `description` - The description of `max_allowed_packet`.

    * `example` - An example of a valid value for `max_allowed_packet`.

    * `maximum` - The maximum valid value of `max_allowed_packet`.

    * `minimum` - The minimum valid value of `max_allowed_packet`.

    * `requires_restart` - Whether changing the value `max_allowed_packet` requires the DB to restart.

    * `type` - The type of the value of `max_allowed_packet`.

    ## max_heap_table_size

    The following arguments are supported in the `max_heap_table_size` specification block:

    * `description` - The description of `max_heap_table_size`.

    * `example` - An example of a valid value for `max_heap_table_size`.

    * `maximum` - The maximum valid value of `max_heap_table_size`.

    * `minimum` - The minimum valid value of `max_heap_table_size`.

    * `requires_restart` - Whether changing the value `max_heap_table_size` requires the DB to restart.

    * `type` - The type of the value of `max_heap_table_size`.

    ## net_buffer_length

    The following arguments are supported in the `net_buffer_length` specification block:

    * `description` - The description of `net_buffer_length`.

    * `example` - An example of a valid value for `net_buffer_length`.

    * `maximum` - The maximum valid value of `net_buffer_length`.

    * `minimum` - The minimum valid value of `net_buffer_length`.

    * `requires_restart` - Whether changing the value `net_buffer_length` requires the DB to restart.

    * `type` - The type of the value of `net_buffer_length`.

    ## net_read_timeout

    The following arguments are supported in the `net_read_timeout` specification block:

    * `description` - The description of `net_read_timeout`.

    * `example` - An example of a valid value for `net_read_timeout`.

    * `maximum` - The maximum valid value of `net_read_timeout`.

    * `minimum` - The minimum valid value of `net_read_timeout`.

    * `requires_restart` - Whether changing the value `net_read_timeout` requires the DB to restart.

    * `type` - The type of the value of `net_read_timeout`.

    ## net_write_timeout

    The following arguments are supported in the `net_write_timeout` specification block:

    * `description` - The description of `net_write_timeout`.

    * `example` - An example of a valid value for `net_write_timeout`.

    * `maximum` - The maximum valid value of `net_write_timeout`.

    * `minimum` - The minimum valid value of `net_write_timeout`.

    * `requires_restart` - Whether changing the value `net_write_timeout` requires the DB to restart.

    * `type` - The type of the value of `net_write_timeout`.

    ## sort_buffer_size

    The following arguments are supported in the `sort_buffer_size` specification block:

    * `description` - The description of `sort_buffer_size`.

    * `example` - An example of a valid value for `sort_buffer_size`.

    * `maximum` - The maximum valid value of `sort_buffer_size`.

    * `minimum` - The minimum valid value of `sort_buffer_size`.

    * `requires_restart` - Whether changing the value `sort_buffer_size` requires the DB to restart.

    * `type` - The type of the value of `sort_buffer_size`.

    ## sql_mode

    The following arguments are supported in the `sql_mode` specification block:

    * `description` - The description of `sql_mode`.

    * `example` - An example of a valid value for `sql_mode`.

    * `maxLength` - The maximum valid length of `sql_mode`.

    * `pattern` - The pattern to match for `sql_mode`.

    * `requires_restart` - Whether changing the value `sql_mode` requires the DB to restart.

    * `type` - The type of the value of `sql_mode`.

    ## sql_require_primary_key

    The following arguments are supported in the `sql_require_primary_key` specification block:

    * `description` - The description of `sql_require_primary_key`.

    * `example` - An example of a valid value for `sql_require_primary_key`.

    * `requires_restart` - Whether changing the value `sql_require_primary_key` requires the DB to restart.

    * `type` - The type of the value of `sql_require_primary_key`.

    ## tmp_table_size

    The following arguments are supported in the `tmp_table_size` specification block:

    * `description` - The description of `tmp_table_size`.

    * `example` - An example of a valid value for `tmp_table_size`.

    * `maximum` - The maximum valid value of `tmp_table_size`.

    * `minimum` - The minimum valid value of `tmp_table_size`.

    * `requires_restart` - Whether changing the value `tmp_table_size` requires the DB to restart.

    * `type` - The type of the value of `tmp_table_size`.

    ## wait_timeout

    The following arguments are supported in the `wait_timeout` specification block:

    * `description` - The description of `wait_timeout`.

    * `example` - An example of a valid value for `wait_timeout`.

    * `maximum` - The maximum valid value of `wait_timeout`.

    * `minimum` - The minimum valid value of `wait_timeout`.

    * `requires_restart` - Whether changing the value `wait_timeout` requires the DB to restart.

    * `type` - The type of the value of `wait_timeout`.
    """
    __args__ = dict()
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('linode:index/getDatabaseMysqlConfig:getDatabaseMysqlConfig', __args__, opts=opts, typ=GetDatabaseMysqlConfigResult).value

    return AwaitableGetDatabaseMysqlConfigResult(
        binlog_retention_periods=pulumi.get(__ret__, 'binlog_retention_periods'),
        id=pulumi.get(__ret__, 'id'),
        mysqls=pulumi.get(__ret__, 'mysqls'))
def get_database_mysql_config_output(opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetDatabaseMysqlConfigResult]:
    """
    Provides information about a Linode MySQL Database's Configuration Options.
    For more information, see the Linode APIv4 docs.

    ## Example Usage

    Get information about a MySQL database's configuration options:

    ```python
    import pulumi
    import pulumi_linode as linode

    my_db_config = linode.get_database_mysql_config()
    ```

    ## binlog_retention_period

    The following arguments are supported in the `binlog_retention_period` specification block:

    * `description` - The description of `binlog_retention_period`.

    * `example` - An example of a valid value for `binlog_retention_period`.

    * `maximum` - The maximum valid value of `binlog_retention_period`.

    * `minimum` - The minimum valid value of `binlog_retention_period`.

    * `requires_restart` - Whether changing the value `binlog_retention_period` requires the DB to restart.

    * `type` - The type of the value of `binlog_retention_period`.

    ## mysql

    The following arguments are supported in the `mysql` specification block:

    * `connect_timeout` - The number of seconds that the mysqld server waits for a connect packet before responding with "Bad handshake".

    * `default_time_zone` - Default server time zone as an offset from UTC (from -12:00 to +12:00), a time zone name, or `SYSTEM` to use the MySQL server default.

    * `group_concat_max_len` - The maximum permitted result length in bytes for the `GROUP_CONCAT()` function.

    * `information_schema_stats_expiry` - The time, in seconds, before cached statistics expire.

    * `innodb_change_buffer_max_size` - Maximum size for the InnoDB change buffer, as a percentage of the total size of the buffer pool. Default is 25.

    * `innodb_flush_neighbors` - Specifies whether flushing a page from the InnoDB buffer pool also flushes other dirty pages in the same extent (default is 1): 0 - dirty pages in the same extent are not flushed, 1 - flush contiguous dirty pages in the same extent, 2 - flush dirty pages in the same extent.

    * `innodb_ft_min_token_size` - Minimum length of words that are stored in an InnoDB FULLTEXT index. Changing this parameter will lead to a restart of the MySQL service.

    * `innodb_ft_server_stopword_table` - This option is used to specify your own InnoDB FULLTEXT index stopword list for all InnoDB tables.

    * `innodb_lock_wait_timeout` - The length of time in seconds an InnoDB transaction waits for a row lock before giving up. Default is 120.

    * `innodb_log_buffer_size` - The size in bytes of the buffer that InnoDB uses to write to the log files on disk.

    * `innodb_online_alter_log_max_size` - The upper limit in bytes on the size of the temporary log files used during online DDL operations for InnoDB tables.

    * `innodb_read_io_threads` - The number of I/O threads for read operations in InnoDB. Default is 4. Changing this parameter will lead to a restart of the MySQL service.

    * `innodb_rollback_on_timeout` - When enabled, a transaction timeout causes InnoDB to abort and roll back the entire transaction. Changing this parameter will lead to a restart of the MySQL service.

    * `innodb_thread_concurrency` - Defines the maximum number of threads permitted inside of InnoDB. Default is 0 (infinite concurrency - no limit).

    * `innodb_write_io_threads` - The number of I/O threads for write operations in InnoDB. Default is 4. Changing this parameter will lead to a restart of the MySQL service.

    * `interactive_timeout` - The number of seconds the server waits for activity on an interactive connection before closing it.

    * `internal_tmp_mem_storage_engine` - The storage engine for in-memory internal temporary tables.

    * `max_allowed_packet` - Size of the largest message in bytes that can be received by the server. Default is 67108864 (64M).

    * `max_heap_table_size` - Limits the size of internal in-memory tables. Also set tmp_table_size. Default is 16777216 (16M).

    * `net_buffer_length` - Start sizes of connection buffer and result buffer. Default is 16384 (16K). Changing this parameter will lead to a restart of the MySQL service.

    * `net_read_timeout` - The number of seconds to wait for more data from a connection before aborting the read.

    * `net_write_timeout` - The number of seconds to wait for a block to be written to a connection before aborting the write.

    * `sort_buffer_size` - Sort buffer size in bytes for ORDER BY optimization. Default is 262144 (256K).

    * `sql_mode` - Global SQL mode. Set to empty to use MySQL server defaults. When creating a new service and not setting this field Aiven default SQL mode (strict, SQL standard compliant) will be assigned.

    * `sql_require_primary_key` - Require primary key to be defined for new tables or old tables modified with ALTER TABLE and fail if missing. It is recommended to always have primary keys because various functionality may break if any large table is missing them.

    * `tmp_table_size` - Limits the size of internal in-memory tables. Also set max_heap_table_size. Default is 16777216 (16M).

    * `wait_timeout` - The number of seconds the server waits for activity on a noninteractive connection before closing it.

    ## connect_timeout

    The following arguments are supported in the `connect_timeout` specification block:

    * `description` - The description of `connect_timeout`.

    * `example` - An example of a valid value for `connect_timeout`.

    * `maximum` - The maximum valid value of  `connect_timeout`.

    * `minimum` - The minimum valid value of  `connect_timeout`.

    * `requires_restart` - Whether changing the value `connect_timeout` requires the DB to restart.

    * `type` - The type of the value of `connect_timeout`.

    ## default_time_zone

    The following arguments are supported in the `default_time_zone` specification block:

    * `description` - The description of `default_time_zone`.

    * `example` - An example of a valid value for `default_time_zone`.

    * `maxLength` - The maximum length of the `default_time_zone` value.

    * `minLength` - The minimum length of the `default_time_zone` value.

    * `pattern` - A regular expression that the `default_time_zone` value must match.

    * `requires_restart` - Whether changing the value `default_time_zone` requires the DB to restart.

    * `type` - The type of the value of `default_time_zone`.

    ## group_concat_max_len

    The following arguments are supported in the `group_concat_max_len` specification block:

    * `description` - The description of `group_concat_max_len`.

    * `example` - An example of a valid value for `group_concat_max_len`.

    * `maximum` - The maximum valid value of `group_concat_max_len`.

    * `minimum` - The minimum valid value of `group_concat_max_len`.

    * `requires_restart` - Whether changing the value `group_concat_max_len` requires the DB to restart.

    * `type` - The type of the value of `group_concat_max_len`.

    ## information_schema_stats_expiry

    The following arguments are supported in the `information_schema_stats_expiry` specification block:

    * `description` - The description of `information_schema_stats_expiry`.

    * `example` - An example of a valid value for `information_schema_stats_expiry`.

    * `maximum` - The maximum valid value of `information_schema_stats_expiry`.

    * `minimum` - The minimum valid value of `information_schema_stats_expiry`.

    * `requires_restart` - Whether changing the value `information_schema_stats_expiry` requires the DB to restart.

    * `type` - The type of the value of `information_schema_stats_expiry`.

    ## innodb_change_buffer_max_size

    The following arguments are supported in the `innodb_change_buffer_max_size` specification block:

    * `description` - The description of `innodb_change_buffer_max_size`.

    * `example` - An example of a valid value for `innodb_change_buffer_max_size`.

    * `maximum` - The maximum valid value of `innodb_change_buffer_max_size`.

    * `minimum` - The minimum valid value of `innodb_change_buffer_max_size`.

    * `requires_restart` - Whether changing the value `innodb_change_buffer_max_size` requires the DB to restart.

    * `type` - The type of the value of `innodb_change_buffer_max_size`.

    ## innodb_flush_neighbors

    The following arguments are supported in the `innodb_flush_neighbors` specification block:

    * `description` - The description of `innodb_flush_neighbors`.

    * `example` - An example of a valid value for `innodb_flush_neighbors`.

    * `maximum` - The maximum valid value of `innodb_flush_neighbors`.

    * `minimum` - The minimum valid value of `innodb_flush_neighbors`.

    * `requires_restart` - Whether changing the value `innodb_flush_neighbors` requires the DB to restart.

    * `type` - The type of the value of `innodb_flush_neighbors`.

    ## innodb_ft_min_token_size

    The following arguments are supported in the `innodb_ft_min_token_size` specification block:

    * `description` - The description of `innodb_ft_min_token_size`.

    * `example` - An example of a valid value for `innodb_ft_min_token_size`.

    * `maximum` - The maximum valid value of `innodb_ft_min_token_size`.

    * `minimum` - The minimum valid value of `innodb_ft_min_token_size`.

    * `requires_restart` - Whether changing the value `innodb_ft_min_token_size` requires the DB to restart.

    * `type` - The type of the value of `innodb_ft_min_token_size`.

    ## innodb_ft_server_stopword_table

    The following arguments are supported in the `innodb_ft_server_stopword_table` specification block:

    * `description` - The description of `innodb_ft_server_stopword_table`.

    * `example` - An example of a valid value for `innodb_ft_server_stopword_table`.

    * `maxLength` - The maximum length of the value for `innodb_ft_server_stopword_table`.

    * `pattern` - A regex pattern that a value of `innodb_ft_server_stopword_table` must match.

    * `requires_restart` - Whether changing the value `innodb_ft_server_stopword_table` requires the DB to restart.

    * `type` - The type of the value of `innodb_ft_server_stopword_table`.

    ## innodb_lock_wait_timeout

    The following arguments are supported in the `innodb_lock_wait_timeout` specification block:

    * `description` - The description of `innodb_lock_wait_timeout`.

    * `example` - An example of a valid value for `innodb_lock_wait_timeout`.

    * `maximum` - The maximum valid value of `innodb_lock_wait_timeout`.

    * `minimum` - The minimum valid value of `innodb_lock_wait_timeout`.

    * `requires_restart` - Whether changing the value `innodb_lock_wait_timeout` requires the DB to restart.

    * `type` - The type of the value of `innodb_lock_wait_timeout`.

    ## innodb_log_buffer_size

    The following arguments are supported in the `innodb_log_buffer_size` specification block:

    * `description` - The description of `innodb_log_buffer_size`.

    * `example` - An example of a valid value for `innodb_log_buffer_size`.

    * `maximum` - The maximum valid value of `innodb_log_buffer_size`.

    * `minimum` - The minimum valid value of `innodb_log_buffer_size`.

    * `requires_restart` - Whether changing the value `innodb_log_buffer_size` requires the DB to restart.

    * `type` - The type of the value of `innodb_log_buffer_size`.

    ## innodb_online_alter_log_max_size

    The following arguments are supported in the `innodb_online_alter_log_max_size` specification block:

    * `description` - The description of `innodb_online_alter_log_max_size`.

    * `example` - An example of a valid value for `innodb_online_alter_log_max_size`.

    * `maximum` - The maximum valid value of `innodb_online_alter_log_max_size`.

    * `minimum` - The minimum valid value of `innodb_online_alter_log_max_size`.

    * `requires_restart` - Whether changing the value `innodb_online_alter_log_max_size` requires the DB to restart.

    * `type` - The type of the value of `innodb_online_alter_log_max_size`.

    ## innodb_read_io_threads

    The following arguments are supported in the `innodb_read_io_threads` specification block:

    * `description` - The description of `innodb_read_io_threads`.

    * `example` - An example of a valid value for `innodb_read_io_threads`.

    * `maximum` - The maximum valid value of `innodb_read_io_threads`.

    * `minimum` - The minimum valid value of `innodb_read_io_threads`.

    * `requires_restart` - Whether changing the value `innodb_read_io_threads` requires the DB to restart.

    * `type` - The type of the value of `innodb_read_io_threads`.

    ## innodb_rollback_on_timeout

    The following arguments are supported in the `innodb_rollback_on_timeout` specification block:

    * `description` - The description of `innodb_rollback_on_timeout`.

    * `example` - An example of a valid value for `innodb_rollback_on_timeout`.

    * `requires_restart` - Whether changing the value `innodb_rollback_on_timeout` requires the DB to restart.

    * `type` - The type of the value of `innodb_rollback_on_timeout`.

    ## innodb_thread_concurrency

    The following arguments are supported in the `innodb_thread_concurrency` specification block:

    * `description` - The description of `innodb_thread_concurrency`.

    * `example` - An example of a valid value for `innodb_thread_concurrency`.

    * `maximum` - The maximum valid value of `innodb_thread_concurrency`.

    * `minimum` - The minimum valid value of `innodb_thread_concurrency`.

    * `requires_restart` - Whether changing the value `innodb_thread_concurrency` requires the DB to restart.

    * `type` - The type of the value of `innodb_thread_concurrency`.

    ## innodb_write_io_threads

    The following arguments are supported in the `innodb_write_io_threads` specification block:

    * `description` - The description of `innodb_write_io_threads`.

    * `example` - An example of a valid value for `innodb_write_io_threads`.

    * `maximum` - The maximum valid value of `innodb_write_io_threads`.

    * `minimum` - The minimum valid value of `innodb_write_io_threads`.

    * `requires_restart` - Whether changing the value `innodb_write_io_threads` requires the DB to restart.

    * `type` - The type of the value of `innodb_write_io_threads`.

    ## interactive_timeout

    The following arguments are supported in the `interactive_timeout` specification block:

    * `description` - The description of `interactive_timeout`.

    * `example` - An example of a valid value for `interactive_timeout`.

    * `maximum` - The maximum valid value of `interactive_timeout`.

    * `minimum` - The minimum valid value of `interactive_timeout`.

    * `requires_restart` - Whether changing the value `interactive_timeout` requires the DB to restart.

    * `type` - The type of the value of `interactive_timeout`.

    ## internal_tmp_mem_storage_engine

    The following arguments are supported in the `internal_tmp_mem_storage_engine` specification block:

    * `description` - The description of `internal_tmp_mem_storage_engine`.

    * `enum` - A list of valid enum values for `internal_tmp_mem_storage_engine`.

    * `example` - An example of a valid value for `internal_tmp_mem_storage_engine`.

    * `requires_restart` - Whether changing the value `internal_tmp_mem_storage_engine` requires the DB to restart.

    * `type` - The type of the value of `internal_tmp_mem_storage_engine`.

    ## max_allowed_packet

    The following arguments are supported in the `max_allowed_packet` specification block:

    * `description` - The description of `max_allowed_packet`.

    * `example` - An example of a valid value for `max_allowed_packet`.

    * `maximum` - The maximum valid value of `max_allowed_packet`.

    * `minimum` - The minimum valid value of `max_allowed_packet`.

    * `requires_restart` - Whether changing the value `max_allowed_packet` requires the DB to restart.

    * `type` - The type of the value of `max_allowed_packet`.

    ## max_heap_table_size

    The following arguments are supported in the `max_heap_table_size` specification block:

    * `description` - The description of `max_heap_table_size`.

    * `example` - An example of a valid value for `max_heap_table_size`.

    * `maximum` - The maximum valid value of `max_heap_table_size`.

    * `minimum` - The minimum valid value of `max_heap_table_size`.

    * `requires_restart` - Whether changing the value `max_heap_table_size` requires the DB to restart.

    * `type` - The type of the value of `max_heap_table_size`.

    ## net_buffer_length

    The following arguments are supported in the `net_buffer_length` specification block:

    * `description` - The description of `net_buffer_length`.

    * `example` - An example of a valid value for `net_buffer_length`.

    * `maximum` - The maximum valid value of `net_buffer_length`.

    * `minimum` - The minimum valid value of `net_buffer_length`.

    * `requires_restart` - Whether changing the value `net_buffer_length` requires the DB to restart.

    * `type` - The type of the value of `net_buffer_length`.

    ## net_read_timeout

    The following arguments are supported in the `net_read_timeout` specification block:

    * `description` - The description of `net_read_timeout`.

    * `example` - An example of a valid value for `net_read_timeout`.

    * `maximum` - The maximum valid value of `net_read_timeout`.

    * `minimum` - The minimum valid value of `net_read_timeout`.

    * `requires_restart` - Whether changing the value `net_read_timeout` requires the DB to restart.

    * `type` - The type of the value of `net_read_timeout`.

    ## net_write_timeout

    The following arguments are supported in the `net_write_timeout` specification block:

    * `description` - The description of `net_write_timeout`.

    * `example` - An example of a valid value for `net_write_timeout`.

    * `maximum` - The maximum valid value of `net_write_timeout`.

    * `minimum` - The minimum valid value of `net_write_timeout`.

    * `requires_restart` - Whether changing the value `net_write_timeout` requires the DB to restart.

    * `type` - The type of the value of `net_write_timeout`.

    ## sort_buffer_size

    The following arguments are supported in the `sort_buffer_size` specification block:

    * `description` - The description of `sort_buffer_size`.

    * `example` - An example of a valid value for `sort_buffer_size`.

    * `maximum` - The maximum valid value of `sort_buffer_size`.

    * `minimum` - The minimum valid value of `sort_buffer_size`.

    * `requires_restart` - Whether changing the value `sort_buffer_size` requires the DB to restart.

    * `type` - The type of the value of `sort_buffer_size`.

    ## sql_mode

    The following arguments are supported in the `sql_mode` specification block:

    * `description` - The description of `sql_mode`.

    * `example` - An example of a valid value for `sql_mode`.

    * `maxLength` - The maximum valid length of `sql_mode`.

    * `pattern` - The pattern to match for `sql_mode`.

    * `requires_restart` - Whether changing the value `sql_mode` requires the DB to restart.

    * `type` - The type of the value of `sql_mode`.

    ## sql_require_primary_key

    The following arguments are supported in the `sql_require_primary_key` specification block:

    * `description` - The description of `sql_require_primary_key`.

    * `example` - An example of a valid value for `sql_require_primary_key`.

    * `requires_restart` - Whether changing the value `sql_require_primary_key` requires the DB to restart.

    * `type` - The type of the value of `sql_require_primary_key`.

    ## tmp_table_size

    The following arguments are supported in the `tmp_table_size` specification block:

    * `description` - The description of `tmp_table_size`.

    * `example` - An example of a valid value for `tmp_table_size`.

    * `maximum` - The maximum valid value of `tmp_table_size`.

    * `minimum` - The minimum valid value of `tmp_table_size`.

    * `requires_restart` - Whether changing the value `tmp_table_size` requires the DB to restart.

    * `type` - The type of the value of `tmp_table_size`.

    ## wait_timeout

    The following arguments are supported in the `wait_timeout` specification block:

    * `description` - The description of `wait_timeout`.

    * `example` - An example of a valid value for `wait_timeout`.

    * `maximum` - The maximum valid value of `wait_timeout`.

    * `minimum` - The minimum valid value of `wait_timeout`.

    * `requires_restart` - Whether changing the value `wait_timeout` requires the DB to restart.

    * `type` - The type of the value of `wait_timeout`.
    """
    __args__ = dict()
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('linode:index/getDatabaseMysqlConfig:getDatabaseMysqlConfig', __args__, opts=opts, typ=GetDatabaseMysqlConfigResult)
    return __ret__.apply(lambda __response__: GetDatabaseMysqlConfigResult(
        binlog_retention_periods=pulumi.get(__response__, 'binlog_retention_periods'),
        id=pulumi.get(__response__, 'id'),
        mysqls=pulumi.get(__response__, 'mysqls')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetDatabaseMysqlResult',
    'AwaitableGetDatabaseMysqlResult',
    'get_database_mysql',
    'get_database_mysql_output',
]

@pulumi.output_type
class GetDatabaseMysqlResult:
    """
    A collection of values returned by getDatabaseMysql.
    """
    def __init__(__self__, allow_lists=None, ca_cert=None, cluster_size=None, created=None, database_id=None, encrypted=None, engine=None, engine_id=None, host_primary=None, host_secondary=None, id=None, label=None, region=None, replication_type=None, root_password=None, root_username=None, ssl_connection=None, status=None, type=None, updated=None, updates=None, version=None):
        if allow_lists and not isinstance(allow_lists, list):
            raise TypeError("Expected argument 'allow_lists' to be a list")
        pulumi.set(__self__, "allow_lists", allow_lists)
        if ca_cert and not isinstance(ca_cert, str):
            raise TypeError("Expected argument 'ca_cert' to be a str")
        pulumi.set(__self__, "ca_cert", ca_cert)
        if cluster_size and not isinstance(cluster_size, int):
            raise TypeError("Expected argument 'cluster_size' to be a int")
        pulumi.set(__self__, "cluster_size", cluster_size)
        if created and not isinstance(created, str):
            raise TypeError("Expected argument 'created' to be a str")
        pulumi.set(__self__, "created", created)
        if database_id and not isinstance(database_id, int):
            raise TypeError("Expected argument 'database_id' to be a int")
        pulumi.set(__self__, "database_id", database_id)
        if encrypted and not isinstance(encrypted, bool):
            raise TypeError("Expected argument 'encrypted' to be a bool")
        pulumi.set(__self__, "encrypted", encrypted)
        if engine and not isinstance(engine, str):
            raise TypeError("Expected argument 'engine' to be a str")
        pulumi.set(__self__, "engine", engine)
        if engine_id and not isinstance(engine_id, str):
            raise TypeError("Expected argument 'engine_id' to be a str")
        pulumi.set(__self__, "engine_id", engine_id)
        if host_primary and not isinstance(host_primary, str):
            raise TypeError("Expected argument 'host_primary' to be a str")
        pulumi.set(__self__, "host_primary", host_primary)
        if host_secondary and not isinstance(host_secondary, str):
            raise TypeError("Expected argument 'host_secondary' to be a str")
        pulumi.set(__self__, "host_secondary", host_secondary)
        if id and not isinstance(id, int):
            raise TypeError("Expected argument 'id' to be a int")
        pulumi.set(__self__, "id", id)
        if label and not isinstance(label, str):
            raise TypeError("Expected argument 'label' to be a str")
        pulumi.set(__self__, "label", label)
        if region and not isinstance(region, str):
            raise TypeError("Expected argument 'region' to be a str")
        pulumi.set(__self__, "region", region)
        if replication_type and not isinstance(replication_type, str):
            raise TypeError("Expected argument 'replication_type' to be a str")
        pulumi.set(__self__, "replication_type", replication_type)
        if root_password and not isinstance(root_password, str):
            raise TypeError("Expected argument 'root_password' to be a str")
        pulumi.set(__self__, "root_password", root_password)
        if root_username and not isinstance(root_username, str):
            raise TypeError("Expected argument 'root_username' to be a str")
        pulumi.set(__self__, "root_username", root_username)
        if ssl_connection and not isinstance(ssl_connection, bool):
            raise TypeError("Expected argument 'ssl_connection' to be a bool")
        pulumi.set(__self__, "ssl_connection", ssl_connection)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if type and not isinstance(type, str):
            raise TypeError("Expected argument 'type' to be a str")
        pulumi.set(__self__, "type", type)
        if updated and not isinstance(updated, str):
            raise TypeError("Expected argument 'updated' to be a str")
        pulumi.set(__self__, "updated", updated)
        if updates and not isinstance(updates, list):
            raise TypeError("Expected argument 'updates' to be a list")
        pulumi.set(__self__, "updates", updates)
        if version and not isinstance(version, str):
            raise TypeError("Expected argument 'version' to be a str")
        pulumi.set(__self__, "version", version)

    @_builtins.property
    @pulumi.getter(name="allowLists")
    def allow_lists(self) -> Sequence[_builtins.str]:
        """
        A list of IP addresses that can access the Managed Database. Each item can be a single IP address or a range in CIDR format.
        """
        return pulumi.get(self, "allow_lists")

    @_builtins.property
    @pulumi.getter(name="caCert")
    def ca_cert(self) -> _builtins.str:
        """
        The base64-encoded SSL CA certificate for the Managed Database instance.
        """
        return pulumi.get(self, "ca_cert")

    @_builtins.property
    @pulumi.getter(name="clusterSize")
    def cluster_size(self) -> _builtins.int:
        """
        The number of Linode Instance nodes deployed to the Managed Database.
        """
        return pulumi.get(self, "cluster_size")

    @_builtins.property
    @pulumi.getter
    def created(self) -> _builtins.str:
        """
        When this Managed Database was created.
        """
        return pulumi.get(self, "created")

    @_builtins.property
    @pulumi.getter(name="databaseId")
    @_utilities.deprecated("""Configure `id` instead. This attribute will be removed in the next major version of the provider.""")
    def database_id(self) -> Optional[_builtins.int]:
        return pulumi.get(self, "database_id")

    @_builtins.property
    @pulumi.getter
    def encrypted(self) -> _builtins.bool:
        """
        Whether the Managed Databases is encrypted.
        """
        return pulumi.get(self, "encrypted")

    @_builtins.property
    @pulumi.getter
    def engine(self) -> _builtins.str:
        """
        The Managed Database engine. (e.g. `mysql`)
        """
        return pulumi.get(self, "engine")

    @_builtins.property
    @pulumi.getter(name="engineId")
    def engine_id(self) -> _builtins.str:
        """
        The Managed Database engine in engine/version format. (e.g. `mysql/8.0.30`)
        """
        return pulumi.get(self, "engine_id")

    @_builtins.property
    @pulumi.getter(name="hostPrimary")
    def host_primary(self) -> _builtins.str:
        """
        The primary host for the Managed Database.
        """
        return pulumi.get(self, "host_primary")

    @_builtins.property
    @pulumi.getter(name="hostSecondary")
    def host_secondary(self) -> _builtins.str:
        """
        The secondary/private network host for the Managed Database.
        """
        return pulumi.get(self, "host_secondary")

    @_builtins.property
    @pulumi.getter
    def id(self) -> Optional[_builtins.int]:
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def label(self) -> _builtins.str:
        """
        A unique, user-defined string referring to the Managed Database.
        """
        return pulumi.get(self, "label")

    @_builtins.property
    @pulumi.getter
    def region(self) -> _builtins.str:
        """
        The region that hosts this Linode Managed Database.
        """
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter(name="replicationType")
    def replication_type(self) -> _builtins.str:
        """
        The replication method used for the Managed Database. (`none`, `asynch`, `semi_synch`)
        """
        return pulumi.get(self, "replication_type")

    @_builtins.property
    @pulumi.getter(name="rootPassword")
    def root_password(self) -> _builtins.str:
        """
        The randomly-generated root password for the Managed Database instance.
        """
        return pulumi.get(self, "root_password")

    @_builtins.property
    @pulumi.getter(name="rootUsername")
    def root_username(self) -> _builtins.str:
        """
        The root username for the Managed Database instance.
        """
        return pulumi.get(self, "root_username")

    @_builtins.property
    @pulumi.getter(name="sslConnection")
    def ssl_connection(self) -> _builtins.bool:
        """
        Whether to require SSL credentials to establish a connection to the Managed Database.
        """
        return pulumi.get(self, "ssl_connection")

    @_builtins.property
    @pulumi.getter
    def status(self) -> _builtins.str:
        """
        The operating status of the Managed Database.
        """
        return pulumi.get(self, "status")

    @_builtins.property
    @pulumi.getter
    def type(self) -> _builtins.str:
        """
        The Linode Instance type used for the nodes of the  Managed Database instance.
        """
        return pulumi.get(self, "type")

    @_builtins.property
    @pulumi.getter
    def updated(self) -> _builtins.str:
        """
        When this Managed Database was last updated.
        """
        return pulumi.get(self, "updated")

    @_builtins.property
    @pulumi.getter
    def updates(self) -> Sequence['outputs.GetDatabaseMysqlUpdateResult']:
        return pulumi.get(self, "updates")

    @_builtins.property
    @pulumi.getter
    def version(self) -> _builtins.str:
        """
        The Managed Database engine version. (e.g. `v8.0.26`)
        """
        return pulumi.get(self, "version")


class AwaitableGetDatabaseMysqlResult(GetDatabaseMysqlResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetDatabaseMysqlResult(
            allow_lists=self.allow_lists,
            ca_cert=self.ca_cert,
            cluster_size=self.cluster_size,
            created=self.created,
            database_id=self.database_id,
            encrypted=self.encrypted,
            engine=self.engine,
            engine_id=self.engine_id,
            host_primary=self.host_primary,
            host_secondary=self.host_secondary,
            id=self.id,
            label=self.label,
            region=self.region,
            replication_type=self.replication_type,
            root_password=self.root_password,
            root_username=self.root_username,
            ssl_connection=self.ssl_connection,
            status=self.status,
            type=self.type,
            updated=self.updated,
            updates=self.updates,
            version=self.version)


def get_database_mysql(database_id: Optional[_builtins.int] = None,
                       id: Optional[_builtins.int] = None,
                       opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetDatabaseMysqlResult:
    """
    > **DEPRECATION NOTICE:** This data source has been deprecated. Please use DatabaseMysqlV2 for all future implementations.

    Provides information about a Linode MySQL Database.
    For more information, see the [Linode APIv4 docs](https://techdocs.akamai.com/linode-api/reference/get-databases-instances).

    ## Example Usage

    Get information about a MySQL database:

    ```python
    import pulumi
    import pulumi_linode as linode

    my_db = linode.get_database_mysql(id=12345)
    ```

    ## updates

    The following arguments are exported by the `updates` specification block:

    * `day_of_week` - The day to perform maintenance. (`monday`, `tuesday`, ...)

    * `duration` - The maximum maintenance window time in hours. (`1`..`3`)

    * `frequency` - Whether maintenance occurs on a weekly or monthly basis. (`weekly`, `monthly`)

    * `hour_of_day` - The hour to begin maintenance based in UTC time. (`0`..`23`)

    * `week_of_month` - The week of the month to perform monthly frequency updates. Required for `monthly` frequency updates. (`1`..`4`)


    :param _builtins.int database_id: The ID of the MySQL database. Deprecated: Use id instead.
    :param _builtins.int id: The ID of the MySQL database. Mutually exclusive with `database_id`.
    """
    __args__ = dict()
    __args__['databaseId'] = database_id
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('linode:index/getDatabaseMysql:getDatabaseMysql', __args__, opts=opts, typ=GetDatabaseMysqlResult).value

    return AwaitableGetDatabaseMysqlResult(
        allow_lists=pulumi.get(__ret__, 'allow_lists'),
        ca_cert=pulumi.get(__ret__, 'ca_cert'),
        cluster_size=pulumi.get(__ret__, 'cluster_size'),
        created=pulumi.get(__ret__, 'created'),
        database_id=pulumi.get(__ret__, 'database_id'),
        encrypted=pulumi.get(__ret__, 'encrypted'),
        engine=pulumi.get(__ret__, 'engine'),
        engine_id=pulumi.get(__ret__, 'engine_id'),
        host_primary=pulumi.get(__ret__, 'host_primary'),
        host_secondary=pulumi.get(__ret__, 'host_secondary'),
        id=pulumi.get(__ret__, 'id'),
        label=pulumi.get(__ret__, 'label'),
        region=pulumi.get(__ret__, 'region'),
        replication_type=pulumi.get(__ret__, 'replication_type'),
        root_password=pulumi.get(__ret__, 'root_password'),
        root_username=pulumi.get(__ret__, 'root_username'),
        ssl_connection=pulumi.get(__ret__, 'ssl_connection'),
        status=pulumi.get(__ret__, 'status'),
        type=pulumi.get(__ret__, 'type'),
        updated=pulumi.get(__ret__, 'updated'),
        updates=pulumi.get(__ret__, 'updates'),
        version=pulumi.get(__ret__, 'version'))
def get_database_mysql_output(database_id: Optional[pulumi.Input[Optional[_builtins.int]]] = None,
                              id: Optional[pulumi.Input[Optional[_builtins.int]]] = None,
                              opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetDatabaseMysqlResult]:
    """
    > **DEPRECATION NOTICE:** This data source has been deprecated. Please use DatabaseMysqlV2 for all future implementations.

    Provides information about a Linode MySQL Database.
    For more information, see the [Linode APIv4 docs](https://techdocs.akamai.com/linode-api/reference/get-databases-instances).

    ## Example Usage

    Get information about a MySQL database:

    ```python
    import pulumi
    import pulumi_linode as linode

    my_db = linode.get_database_mysql(id=12345)
    ```

    ## updates

    The following arguments are exported by the `updates` specification block:

    * `day_of_week` - The day to perform maintenance. (`monday`, `tuesday`, ...)

    * `duration` - The maximum maintenance window time in hours. (`1`..`3`)

    * `frequency` - Whether maintenance occurs on a weekly or monthly basis. (`weekly`, `monthly`)

    * `hour_of_day` - The hour to begin maintenance based in UTC time. (`0`..`23`)

    * `week_of_month` - The week of the month to perform monthly frequency updates. Required for `monthly` frequency updates. (`1`..`4`)


    :param _builtins.int database_id: The ID of the MySQL database. Deprecated: Use id instead.
    :param _builtins.int id: The ID of the MySQL database. Mutually exclusive with `database_id`.
    """
    __args__ = dict()
    __args__['databaseId'] = database_id
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('linode:index/getDatabaseMysql:getDatabaseMysql', __args__, opts=opts, typ=GetDatabaseMysqlResult)
    return __ret__.apply(lambda __response__: GetDatabaseMysqlResult(
        allow_lists=pulumi.get(__response__, 'allow_lists'),
        ca_cert=pulumi.get(__response__, 'ca_cert'),
        cluster_size=pulumi.get(__response__, 'cluster_size'),
        created=pulumi.get(__response__, 'created'),
        database_id=pulumi.get(__response__, 'database_id'),
        encrypted=pulumi.get(__response__, 'encrypted'),
        engine=pulumi.get(__response__, 'engine'),
        engine_id=pulumi.get(__response__, 'engine_id'),
        host_primary=pulumi.get(__response__, 'host_primary'),
        host_secondary=pulumi.get(__response__, 'host_secondary'),
        id=pulumi.get(__response__, 'id'),
        label=pulumi.get(__response__, 'label'),
        region=pulumi.get(__response__, 'region'),
        replication_type=pulumi.get(__response__, 'replication_type'),
        root_password=pulumi.get(__response__, 'root_password'),
        root_username=pulumi.get(__response__, 'root_username'),
        ssl_connection=pulumi.get(__response__, 'ssl_connection'),
        status=pulumi.get(__response__, 'status'),
        type=pulumi.get(__response__, 'type'),
        updated=pulumi.get(__response__, 'updated'),
        updates=pulumi.get(__response__, 'updates'),
        version=pulumi.get(__response__, 'version')))
